[llvm] e4ea2d5 - [StructurizeCFG] Correctly depend on UniformityAnalysis
via llvm-commits
llvm-commits at lists.llvm.org
Tue Mar 14 03:26:38 PDT 2023
Author: pvanhout
Date: 2023-03-14T11:25:22+01:00
New Revision: e4ea2d59191c7b94a3805cfd3adda1db6d17852a
URL: https://github.com/llvm/llvm-project/commit/e4ea2d59191c7b94a3805cfd3adda1db6d17852a
DIFF: https://github.com/llvm/llvm-project/commit/e4ea2d59191c7b94a3805cfd3adda1db6d17852a.diff
LOG: [StructurizeCFG] Correctly depend on UniformityAnalysis
Small oversight in https://reviews.llvm.org/D145688 - the pass' dependency was not updated to reflect the change to UA.
Also, change DivergenceAnalysis to UniformityAnalysis in a comment. That way, StructurizeCFG only refers to UA and not DA anymore.
Added:
Modified:
llvm/lib/Transforms/Scalar/StructurizeCFG.cpp
Removed:
################################################################################
diff --git a/llvm/lib/Transforms/Scalar/StructurizeCFG.cpp b/llvm/lib/Transforms/Scalar/StructurizeCFG.cpp
index 62bd40a28eb86..a7609f0b60069 100644
--- a/llvm/lib/Transforms/Scalar/StructurizeCFG.cpp
+++ b/llvm/lib/Transforms/Scalar/StructurizeCFG.cpp
@@ -367,7 +367,7 @@ char StructurizeCFGLegacyPass::ID = 0;
INITIALIZE_PASS_BEGIN(StructurizeCFGLegacyPass, "structurizecfg",
"Structurize the CFG", false, false)
-INITIALIZE_PASS_DEPENDENCY(LegacyDivergenceAnalysis)
+INITIALIZE_PASS_DEPENDENCY(UniformityInfoWrapperPass)
INITIALIZE_PASS_DEPENDENCY(LowerSwitchLegacyPass)
INITIALIZE_PASS_DEPENDENCY(DominatorTreeWrapperPass)
INITIALIZE_PASS_DEPENDENCY(RegionInfoPass)
@@ -1085,7 +1085,7 @@ static bool hasOnlyUniformBranches(Region *R, unsigned UniformMDKindID,
<< " has uniform terminator\n");
} else {
// Explicitly refuse to treat regions as uniform if they have non-uniform
// subregions. We cannot rely on DivergenceAnalysis for branches in
// subregions because those branches may have been removed and re-created,
// so we look for our metadata instead.
//
@@ -1085,7 +1085,7 @@ static bool hasOnlyUniformBranches(Region *R, unsigned UniformMDKindID,
} else {
// Explicitly refuse to treat regions as uniform if they have non-uniform
- // subregions. We cannot rely on DivergenceAnalysis for branches in
+ // subregions. We cannot rely on UniformityAnalysis for branches in
// subregions because those branches may have been removed and re-created,
// so we look for our metadata instead.
More information about the llvm-commits
mailing list